package com.citra.pivot.demo;

import java.sql.Connection;
import java.sql.DriverManager;

import org.olap4j.OlapConnection;
import org.olap4j.OlapWrapper;

import com.citra.pivot.PivotTable;
import com.citra.pivot.olap.DefaultOlapProvider;
import com.citra.pivot.olap.OlapDefinition;
import com.citra.pivot.olap.OlapUtils;
import com.citra.pivot.olap.data.DataSource;
import com.citra.pivot.olap.data.DataSourceException;
import com.citra.pivot.olap4j.Olap4jDataSource;
/**
 * Pivot table demo for use with a mondrian database.
 */
public class MondrianDemo extends AbstractOlapDemo {
	/** whether to use the olap4j generic driver or the mondrian specific */
	protected boolean useOlap4jXmla;
/**
 *
 */
public MondrianDemo() {
	this(true);
}
/**
 *
 */
public MondrianDemo(boolean useOlap4jXmla) {
	this(useOlap4jXmla, true);
}
/**
 *
 */
public MondrianDemo(boolean useOlap4jXmla, boolean useRemote) {
	super(useRemote);

	this.useOlap4jXmla = useOlap4jXmla;
}
/**
 *
 */
protected DataSource createDataSource() {
	try {
		DataSource ds = new Olap4jDataSource(getConnection());
		return ds;
	} catch (Exception e) {
		e.printStackTrace();
		return null;
	}
}
/**
 *
 */
protected void customizeTable(PivotTable pivotTable, DefaultOlapProvider provider) {
	//get pivot definition in order to modify it
	OlapDefinition def = provider.getOlapDefinition();
	//modify definition
	//set time to rows
	def.setHierarchy(OlapUtils.findHierarchyByName(def.getCube(), "Time"), OlapDefinition.ROW_TYPE);
	//set measures to columns
	def.setHierarchy(def.getMeasureHierarchy(), OlapDefinition.COLUMN_TYPE);

	//set new definition
	try {
		provider.setOlapDefinition(def);
	} catch (DataSourceException e) {
		e.printStackTrace();
	}
}
/**
 *
 */
public OlapConnection getConnection() throws Exception {
	if (useOlap4jXmla) return getMondrianConnectionOlap4j();
	else return getMondrianConnectionGeneric();
}
/**
 *
 */
public static OlapConnection getMondrianConnectionGeneric() throws Exception {
	//db
	Class.forName("mondrian.olap4j.MondrianOlap4jDriver");
	Connection connection = DriverManager.getConnection("jdbc:mondrian:Jdbc=jdbc:odbc:MondrianFoodMart;Catalog=c:\\FoodMart.xml;");

	OlapWrapper wrapper = (OlapWrapper) connection;
	OlapConnection olapConnection = (OlapConnection) wrapper.unwrap(OlapConnection.class);
	return olapConnection;
}
/**
 *
 */
public static OlapConnection getMondrianConnectionOlap4j() throws Exception {
	//db
	Class.forName("org.olap4j.driver.xmla.XmlaOlap4jDriver");
	Connection	connection = DriverManager.getConnection("jdbc:xmla:Server=http://localhost:8080/mondrian/xmla;Catalog=FoodMart;");

	OlapWrapper wrapper = (OlapWrapper) connection;
	OlapConnection olapConnection = (OlapConnection) wrapper.unwrap(OlapConnection.class);
	return olapConnection;
}
/**
 *
 */
public static void main(String[] args) {
	//run demo
	MondrianDemo demo = new MondrianDemo();
	try {
		//show
		demo.show();
	}
	catch (Exception e) {
		e.printStackTrace();
	}
}
}
